@@ -24,7 +24,7 @@
 
 __author__ = "Dilshod Temirkhodjaev <tdilshod@gmail.com>"
 __license__ = "MIT"
-__version__ = "0.8.2"
+__version__ = "0.8.3"
 
 import csv, datetime, zipfile, sys, os, re, signal, io
 import xml.parsers.expat
@@ -222,11 +222,12 @@ class Xlsx2csv:
         self.shared_strings = self._parse(SharedStrings, self.content_types.types["shared_strings"])
         self.styles = self._parse(Styles, self.content_types.types["styles"])
         self.workbook = self._parse(Workbook, self.content_types.types["workbook"])
-        workbook_relationships = list(filter(lambda r: "book" in r, self.content_types.types["relationships"]))[0]
-        self.workbook.relationships = self._parse(Relationships, workbook_relationships)
-        if self.options['no_line_breaks']:
-            self.shared_strings.replace_line_breaks()
-        elif self.options['escape_strings']:
+        workbook_relationships = list(filter(lambda r: "book" in r, self.content_types.types["relationships"]))
+        if len(workbook_relationships) > 0:
+            self.workbook.relationships = self._parse(Relationships, workbook_relationships[0])
+        else:
+            self.workbook.relationships = Relationships()
+        if self.options['escape_strings']:
             self.shared_strings.escape_strings()
 
     def __del__(self):
@@ -362,6 +363,7 @@ class Xlsx2csv:
                 sheet.set_scifloat(self.options['scifloat'])
                 sheet.set_ignore_formats(self.options['ignore_formats'])
                 sheet.set_skip_hidden_rows(self.options['skip_hidden_rows'])
+                sheet.set_no_line_breaks(self.options['no_line_breaks'])
                 if self.options['escape_strings'] and sheet.filedata:
                     sheet.filedata = re.sub(r"(<v>[^<>]+)&#10;([^<>]+</v>)", r"\1\\n\2",
                                             re.sub(r"(<v>[^<>]+)&#9;([^<>]+</v>)", r"\1\\t\2",
@@ -671,6 +673,7 @@ class Sheet:
         self.mergeCells = {}
         self.ignore_formats = []
         self.skip_hidden_rows = False
+        self.no_line_breaks = False
 
         self.colIndex = 0
         self.colNum = ""
@@ -701,6 +704,9 @@ class Sheet:
     def set_skip_hidden_rows(self, skip_hidden_rows):
         self.skip_hidden_rows = skip_hidden_rows
 
+    def set_no_line_breaks(self, no_line_breaks):
+        self.no_line_breaks = no_line_breaks
+
     def set_merge_cells(self, mergecells):
         if not mergecells:
             return
@@ -833,7 +839,7 @@ class Sheet:
                 if format_str in FORMATS:
                     format_type = FORMATS[format_str]
                 elif re.match(r"^\d+(\.\d+)?$", self.data) and re.match(".*[hsmdyY]", format_str) and not re.match(
-                        '.*\[.*[dmhys].*\]', format_str):
+                        r".*\[.*[dmhys].*\]", format_str):
                     # it must be date format
                     if float(self.data) < 1:
                         format_type = "time"
@@ -955,6 +961,9 @@ class Sheet:
                 else:
                     d = self.mergeCells[self.mergeCells[self.colNum + self.rowNum]['copyFrom']]['value']
 
+            if self.no_line_breaks:
+              d = d.replace("\r", " ").replace("\n", " ").replace("\t", " ")
+
             self.columns[t - 1 + self.colIndex] = d
             self.in_cell = False
 
